/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation version 3.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see https://www.gnu.org/licenses
*/

// This one goes to the Arduino inside the amplifier

#include <Bounce2.h>
#include <Wire.h>

// Relays
const int REL1 = 2;
const int REL2 = 3;
const int REL3 = 4;
const int REL4 = 5;
const int REL5 = 6;

// Momentary switches
const int SW1_PIN = 7;
const int SW2_PIN = 8;
const int SW3_PIN = 9;
const int SW4_PIN = 10;

// Set default channel
int CHANNEL = 1;

int PREVIOUS_CHANNEL;

// INSTANTIATE Button OBJECTS
Bounce2::Button button1 = Bounce2::Button();
Bounce2::Button button2 = Bounce2::Button();
Bounce2::Button button3 = Bounce2::Button();
Bounce2::Button button4 = Bounce2::Button();

void setup() {
  // put your setup code here, to run once:
  Serial.begin(9600);

  // Start the I2C Bus as Slave on address 9
  Wire.begin(9); 
  // Attach a function to trigger when something is received.
  Wire.onReceive(receiveEvent);

  // Button setup
  button1.attach( SW1_PIN, INPUT_PULLUP );
  button2.attach( SW2_PIN, INPUT_PULLUP );
  button3.attach( SW3_PIN, INPUT_PULLUP );
  button4.attach( SW4_PIN, INPUT_PULLUP );

  // Debounce interval in ms
  button1.interval(10);
  button2.interval(10);
  button3.interval(10);
  button4.interval(10);

  // Indicate that the low state corresponds to physically pressing the button
  button1.setPressedState(LOW);
  button2.setPressedState(LOW);
  button3.setPressedState(LOW);
  button4.setPressedState(LOW);

  // Set relay pins to output
  pinMode(REL1, OUTPUT);
  pinMode(REL2, OUTPUT);
  pinMode(REL3, OUTPUT);
  pinMode(REL4, OUTPUT);
  pinMode(REL5, OUTPUT);

  digitalWrite(REL1, LOW);
  digitalWrite(REL2, LOW);
  digitalWrite(REL3, LOW);
  digitalWrite(REL4, LOW);
  digitalWrite(REL5, LOW);

}

void receiveEvent(int bytes) {
  CHANNEL = Wire.read();    // read one character from the I2C
}

void loop() {
  // put your main code here, to run repeatedly:

  // Update the buttons
  button1.update();
  button2.update();
  button3.update();
  button4.update();

  if (button1.pressed() ) {
    CHANNEL = 1;
  }
  if (button2.pressed() ) {
    CHANNEL = 2;
  }
  if (button3.pressed() ) {
    CHANNEL = 3;
  }
  if (button4.pressed() ) {
    CHANNEL = 4;
  }
  if (CHANNEL != PREVIOUS_CHANNEL) {
    Serial.print("Channel: ");
    Serial.println(CHANNEL);
  }
  PREVIOUS_CHANNEL = CHANNEL;

  if (CHANNEL == 1) {
    digitalWrite(REL1, HIGH);
    digitalWrite(REL2, LOW);
    digitalWrite(REL3, LOW);
    digitalWrite(REL4, LOW);
    digitalWrite(REL5, LOW);
  }
  if (CHANNEL == 2) {
    digitalWrite(REL1, LOW);
    digitalWrite(REL2, HIGH);
    digitalWrite(REL3, LOW);
    digitalWrite(REL4, LOW);
    digitalWrite(REL5, LOW);
  }
  if (CHANNEL == 3) {
    digitalWrite(REL1, LOW);
    digitalWrite(REL2, LOW);
    digitalWrite(REL3, HIGH);
    digitalWrite(REL4, LOW);
    digitalWrite(REL5, LOW);
  }
  if (CHANNEL == 4) {
    digitalWrite(REL1, LOW);
    digitalWrite(REL2, LOW);
    digitalWrite(REL3, LOW);
    digitalWrite(REL4, HIGH);
    digitalWrite(REL5, LOW);
  }

}
